@@ -6,4 +6,4 @@
 # @Desc    : 
 
 
-from gopup.my_fun import gopup_test, add_sum
+from gopup.my_fun import (gopup_test, add_sum)
